.. _howto:

Why and how
===========

We believe the most effective way of learning how a tool works is using it. This
is why we decided to offer a set of documentation pages aimed at offering
practical insights for the most common tasks involved in the development of
custom components and pipelines.

You will see:

- how to :doc:`design and create custom nodes <create_nodes>` using the simple
  functionalities included in juturna
- how to :doc:`create full pipelines <create_pipelines>` to deploy locally
- how to :doc:`work with environment variables <environment>`  to have a better
  grip on the juturna internals
- how to :doc:`deploy components remotely <remotise_node>` and use them as if
  they were local
- how to :doc:`use the CLI tools <use_cli>` offered by juturna
- how to :doc:`observe juturna pipelines <observe>`
